@@ -4,6 +4,7 @@ var map;
 var marker;
 var infowindow;
 var geocoder;
+var circle_markers = [];
 var markers = [];
 var id_address;
 var id_lng;
@@ -13,7 +14,7 @@ var resizable = false;
 var mouseX, mouseY, drawnX, drawnY, diffX, diffY;
 var has_typecontrol = false;
 
-function initializeMap(map_tid, address_tid, lng_tid, lat_tid, marker_name, is_resize) {
+function initializeMap(map_tid, address_tid, lng_tid, lat_tid, marker_name, is_resize, is_offset) {
     var latlng = new google.maps.LatLng(0, 0);
     var myOptions = {
         zoom: 2,
@@ -38,6 +39,7 @@ function initializeMap(map_tid, address_tid, lng_tid, lat_tid, marker_name, is_r
         initMarker(address_tid, lng_tid, lat_tid);
         initSearch();
         if(is_resize) initResize();
+        if(is_offset) initOffset();
     });
 }
 
@@ -125,7 +127,7 @@ function initMarker(address_tid, lng_tid, lat_tid) {
             position: latlng,
             map: map
         });
-        markers.push(marker);
+        circle_markers.push(marker);
         if (!address) {
             getAddress(new google.maps.LatLng(lat, lng), address);
         } else {
@@ -140,7 +142,7 @@ function initMarker(address_tid, lng_tid, lat_tid) {
                     position: results[0].geometry.location,
                     map: map
                 });
-                markers.push(marker);
+                circle_markers.push(marker);
                 attachSecretMessage(marker, location, address);
             } else {
                 //alert("Unable to resolve the address of the reasons: " + status);
@@ -164,6 +166,8 @@ function addMarker(marker_name) {
                 //icon: "http://maps.google.com/mapfiles/marker_green.png"
             });
 
+            markers.push(marker);
+
 //            google.maps.event.addListener(marker, 'click', function (event) {
 //                clearOverlays(marker);
 //                placeMarker(event.latLng);
@@ -187,13 +191,13 @@ function addMarker(marker_name) {
 
 function placeMarker(location) {
     //Clear all marker
-    clearOverlays(markers, infowindow);
+    clearOverlays(circle_markers, infowindow);
     marker = new google.maps.Marker({
         icon: "/static/img/marker_circle.png",
         position: location,
         map: map
     });
-    markers.push(marker);
+    circle_markers.push(marker);
     //Get address by location
     getAddress(location);
 }
@@ -270,6 +274,46 @@ function initResize() {
     });
 }
 
+function initOffset() {
+    $("#btn_offset").on("click", function(){
+        var offset = $("#id_offset").val();
+        if(offset){
+            $.each(markers, function(key, item){
+                var lat = parseFloat(item.getPosition().lat());
+                var lng = parseFloat(item.getPosition().lng());
+                var rn = random_num(-offset, offset);
+                lat = lat + rn;
+                lng = lng + rn;
+                item.setPosition(new google.maps.LatLng(lat, lng));
+            });
+        }
+    });
+}
+
+function random_num(min, max) {
+    return parseInt(Math.random() * (max - min + 1) + min);
+}
+
+/*function find_num(array, sum) {
+    if (array && array.length > 0) {
+        var begin = 0;
+        var end = array.length - 1;
+
+        while (begin < end) {
+            var current_sum = Math.pow(array[begin], 2) + Math.pow(array[end], 2);
+            if (current_sum < sum) {
+                begin++;
+            } else if (current_sum > sum) {
+                end--;
+            } else {
+                console.log(array[begin] + "   " + array[end]);
+                begin++;
+                end--;
+            }
+        }
+    }
+}*/
+
 function cleanTerms(delay){
     var node = map.getDiv();
     var childNodes = node.firstChild.childNodes;
@@ -371,6 +415,7 @@ $(function(){
                                 position: location,
                                 map: map
                             });
+                            markers.push(marker);
                         });
                     }
                 }
