@@ -7,7 +7,7 @@ register = template.Library()
 
 
 @register.inclusion_tag('gmap/ip_on_map.html', takes_context=True)
-def ip_on_map(context, ip_arg, width=None, height=400, show_input=False):
+def ip_on_map(context, ip_arg, width=None, height=400, show_input=False, is_offset=False):
     if isinstance(ip_arg, list):
         ip_list = ip_arg
     elif isinstance(ip_arg, SafeText):
@@ -19,7 +19,8 @@ def ip_on_map(context, ip_arg, width=None, height=400, show_input=False):
         'location_list': location_list,
         'width': '%d%s' % (width, 'px') if width else '100%',
         'height': '%d%s' % (height, 'px'),
-        'is_resize': 'false',
+        'is_resize': False,
         'show_input': show_input,
+        'is_offset': is_offset,
     })
-    return context
+    return context
\ No newline at end of file
